@@ -1,11 +1,10 @@
 import sqlalchemy as sa
-from sqlalchemy_continuum import Versioned
 from tests import TestCase
 
 
 class TestJoinTableInheritance(TestCase):
     def create_models(self):
-        class TextItem(self.Model, Versioned):
+        class TextItem(self.Model):
             __tablename__ = 'text_item'
             __versioned__ = {
                 'base_classes': (self.Model, )
@@ -42,7 +41,7 @@ class TestJoinTableInheritance(TestCase):
         self.Article = Article
         self.BlogPost = BlogPost
 
-    def test_each_class_has_distinct_translation_class(self):
+    def test_each_class_has_distinct_history_class(self):
         TextItemHistory = self.TextItem.__versioned__['class']
         ArticleHistory = self.Article.__versioned__['class']
         BlogPostHistory = self.BlogPost.__versioned__['class']
