@@ -1,5 +1,4 @@
 import sqlalchemy as sa
-from sqlalchemy_continuum import Versioned
 from tests import TestCase
 
 
@@ -99,7 +98,7 @@ class TestUpdate(TestCase):
 
 class TestUpdateWithDefaultValues(TestCase):
     def create_models(self):
-        class Article(self.Model, Versioned):
+        class Article(self.Model):
             __tablename__ = 'article'
             __versioned__ = {
                 'base_classes': (self.Model, )
